@@ -97,21 +97,17 @@ sub _cut_log ($self) {
 }
 
 sub _run_jshint ($self) {
-    my $jshint_output = [];
-
     my $jshint_args = $self->dist_cfg->{jshint} || $self->src_cfg->{jshint};
 
     my $in_temp = P->file1->tempfile;
-
     P->file->write_bin( $in_temp, $self->{data} );
 
-    my $out_temp = "$ENV->{TEMP_DIR}/tmp-jshint-" . int rand 99_999;
-
-    my $proc = P->sys->run_proc( qq[jshint $jshint_args "$in_temp" > "$out_temp"], win32_create_no_window => 1 )->wait;
-
-    $jshint_output = P->file->read_lines($out_temp);
-
-    unlink $out_temp;    ## no critic qw[InputOutput::RequireCheckedSyscalls]
+    my $proc = P->sys->run_proc(
+        qq[jshint $jshint_args "$in_temp"],
+        use_fh => 1,
+        stdout => 1,
+        stderr => 1,
+    )->capture;
 
     my $res = {
         has_errors => 0,
@@ -119,7 +115,7 @@ sub _run_jshint ($self) {
         data       => [],
     };
 
-    for my $line ( $jshint_output->@* ) {
+    for my $line ( split /\n/sm, $proc->{stdout}->$* ) {
         next unless $line =~ s/^.+?: line/line/smg;
 
         my $descriptor = { raw => $line };
@@ -143,57 +139,55 @@ sub _run_jshint ($self) {
     return $res;
 }
 
-sub _run_eslint ($self) {
+# sub _run_eslint ($self) {
 
-    # my $jshint_args = $self->dist_cfg->{jshint} || $self->src_cfg->{jshint};
+#     # my $jshint_args = $self->dist_cfg->{jshint} || $self->src_cfg->{jshint};
 
-    my $in_temp = P->file1->tempfile;
+#     my $in_temp = P->file1->tempfile;
 
-    P->file->write_bin( $in_temp, $self->{data} );
+#     P->file->write_bin( $in_temp, $self->{data} );
 
-    my $out_temp = "$ENV->{TEMP_DIR}/tmp-jshint-@{[ int rand 99_999 ]}.json";
+#     my $out_temp = "$ENV->{TEMP_DIR}/tmp-jshint-@{[ int rand 99_999 ]}.json";
 
-    my $config = '/var/local/pcore-lib/arbitrator/data/cdn/app/09bc0f7872d3f6ddeae90acd113c0cab/.eslintrc.yaml';
+#     my $config = '/var/local/pcore-lib/arbitrator/data/cdn/app/09bc0f7872d3f6ddeae90acd113c0cab/.eslintrc.yaml';
 
-    my $proc = P->sys->run_proc( qq[eslint --format json --config "$config" -o "$out_temp" "$in_temp"], win32_create_no_window => 1 )->wait;
+#     my $proc = P->sys->run_proc( qq[eslint --format json --config "$config" -o "$out_temp" "$in_temp"] )->wait;
 
-    my $jshint_output = P->cfg->read($out_temp);
+#     my $jshint_output = P->cfg->read($out_temp);
 
-    say dump $jshint_output;
+#     unlink $out_temp;    ## no critic qw[InputOutput::RequireCheckedSyscalls]
 
-    unlink $out_temp;    ## no critic qw[InputOutput::RequireCheckedSyscalls]
+#     my $res = {
+#         has_errors => 0,
+#         has_warns  => 0,
+#         data       => [],
+#     };
 
-    my $res = {
-        has_errors => 0,
-        has_warns  => 0,
-        data       => [],
-    };
+#     return $res;
 
-    return $res;
+#     # for my $line ( $jshint_output->@* ) {
+#     #     next unless $line =~ s/^.+?: line/line/smg;
 
-    # for my $line ( $jshint_output->@* ) {
-    #     next unless $line =~ s/^.+?: line/line/smg;
+#     #     my $descriptor = { raw => $line };
 
-    #     my $descriptor = { raw => $line };
+#     #     ( $descriptor->{line}, $descriptor->{col}, $descriptor->{msg}, $descriptor->{code} ) = $line =~ /line (\d+), col (\d+|undefined), (.+)? [(]([WE]\d+)[)]/sm;
 
-    #     ( $descriptor->{line}, $descriptor->{col}, $descriptor->{msg}, $descriptor->{code} ) = $line =~ /line (\d+), col (\d+|undefined), (.+)? [(]([WE]\d+)[)]/sm;
+#     #     if ( index( $descriptor->{code}, 'E', 0 ) == 0 ) {
+#     #         $descriptor->{is_error} = 1;
 
-    #     if ( index( $descriptor->{code}, 'E', 0 ) == 0 ) {
-    #         $descriptor->{is_error} = 1;
+#     #         $res->{has_errors}++;
+#     #     }
+#     #     else {
+#     #         $descriptor->{is_warn} = 1;
 
-    #         $res->{has_errors}++;
-    #     }
-    #     else {
-    #         $descriptor->{is_warn} = 1;
+#     #         $res->{has_warns}++;
+#     #     }
 
-    #         $res->{has_warns}++;
-    #     }
+#     #     push $res->{data}->@*, $descriptor;
+#     # }
 
-    #     push $res->{data}->@*, $descriptor;
-    # }
-
-    # return $res;
-}
+#     # return $res;
+# }
 
 1;
 ## -----SOURCE FILTER LOG BEGIN-----
@@ -203,8 +197,6 @@ sub _run_eslint ($self) {
 ## | Sev. | Lines                | Policy                                                                                                         |
 ## |======+======================+================================================================================================================|
 ## |    3 | 92                   | RegularExpressions::ProhibitComplexRegexes - Split long regexps into smaller qr// chunks                       |
-## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
-## |    3 | 146                  | Subroutines::ProhibitUnusedPrivateSubroutines - Private subroutine/method '_run_eslint' declared but not used  |
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ##
 ## -----SOURCE FILTER LOG END-----
