@@ -1,9 +1,9 @@
 package Pcore::WebSocket::pcore;
 
 use Pcore -class, -const, -res;
-use Pcore::Lib::Data qw[to_b64];
-use Pcore::Lib::UUID qw[uuid_v1mc_str];
-use Pcore::Lib::Scalar qw[is_res weaken is_plain_arrayref];
+use Pcore::Util::Data qw[to_b64];
+use Pcore::Util::UUID qw[uuid_v1mc_str];
+use Pcore::Util::Scalar qw[is_res weaken is_plain_arrayref];
 use Clone qw[];
 
 with qw[Pcore::WebSocket::Handle];
@@ -32,8 +32,8 @@ const our $TX_TYPE_AUTH  => 'auth';
 const our $TX_TYPE_EVENT => 'event';
 const our $TX_TYPE_RPC   => 'rpc';
 
-my $CBOR = Pcore::Lib::Data::get_cbor();
-my $JSON = Pcore::Lib::Data::get_json( utf8 => 1 );
+my $CBOR = Pcore::Util::Data::get_cbor();
+my $JSON = Pcore::Util::Data::get_json( utf8 => 1 );
 
 sub rpc_call ( $self, $method, @args ) {
 
@@ -206,7 +206,7 @@ sub _on_message ( $self, $msg ) {
                 if ( my $cb = delete $self->{_rpc_cb}->{ $tx->{tid} } ) {
 
                     # convert result to response object
-                    $cb->( bless $tx->{result}, 'Pcore::Lib::Result::Class' );
+                    $cb->( bless $tx->{result}, 'Pcore::Util::Result::Class' );
                 }
             }
         }
@@ -255,7 +255,7 @@ sub _on_auth_request ( $self, $tx ) {
 sub _on_auth_response ( $self, $tx ) {
 
     # create and store auth object
-    $self->{auth} = bless $tx->{auth}, 'Pcore::Lib::Result::Class';
+    $self->{auth} = bless $tx->{auth}, 'Pcore::Util::Result::Class';
 
     # set events listeners
     $self->_bind_events( $tx->{bindings} ) if defined $tx->{bindings};
